@@ -2,5 +2,5 @@ from intuitive_vectorscript.item_multiple_choices import *
 from intuitive_vectorscript.item_single_value_field import *
 from intuitive_vectorscript.dialog_item import *
 from intuitive_vectorscript.dialog import *
-from usefull_classes import *
-from usefull_functions import *
+from intuitive_vectorscript.usefull_classes import *
+from intuitive_vectorscript.usefull_functions import *
